@@ -3,7 +3,7 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.061';
+   our $VERSION = '0.062';
    
    use Exporter 'import';
    
@@ -34,6 +34,13 @@ sub new{
 		convert($textGUI, $target);
 		return GFtk->new(); 
 	}
+	elsif ($target =~m/win32/i){
+		eval " use GFwin32 qw<addButton addStatText addTextCtrl addMenuBits addPanel setScale 
+		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		convert($textGUI, $target);
+		return GFtk->new(); 
+	}
+	
 }
 
 
